import { MinecraftEffectTypes, EffectType, world, BlockPermutation, MinecraftBlockTypes } from "@minecraft/server"
const getScore = (objective, target, useZero = true) => {
    try {
        const obj = world.scoreboard.getObjective(objective);
        if (typeof target == 'string') {
            return obj.getScore(obj.getParticipants().find(v => v.displayName == target));
        }
        return obj.getScore(target.scoreboard);
    } catch {
        return useZero ? 0 : NaN;
    }
}
world.events.entityHurt.subscribe(r => {
    const hurt = r.damagingEntity
    const victim = r.hurtEntity
    if (!victim) return;
    if (!hurt) return;
    if (hurt.hasTag("k") && hurt.typeId == "minecraft:player" && victim.typeId == "minecraft:player") {
        hurt.removeTag("k")
        victim.addTag("k")
        victim.runCommandAsync(`say I am the Victim`)
    }
    if (hurt.hasTag("coin") && victim.hasTag("coin")) {
        if (getScore("coin", victim) > 5) {
            victim.runCommandAsync("scoreboard players remove @s coin 5")
            hurt.addEffect(MinecraftEffectTypes.weakness, 200, 225, true)
            victim.runCommandAsync("execute at @r[type=armor_stand,name=coin] summon s:coin ~ ~-2 ~")
            victim.runCommandAsync("execute at @r[type=armor_stand,name=coin] summon s:coin ~ ~-2 ~")
            victim.runCommandAsync("execute at @r[type=armor_stand,name=coin] summon s:coin ~ ~-2 ~")
            victim.runCommandAsync("execute at @r[type=armor_stand,name=coin] summon s:coin ~ ~-2 ~")
            victim.runCommandAsync("execute at @r[type=armor_stand,name=coin] summon s:coin ~ ~-2 ~")
        }
    }
    if (hurt.hasTag("knock") && victim.hasTag("knock")) {
        if (getScore("knock", hurt) > 4) {
            hurt.runCommandAsync("execute at @a if score @s knock matches ..0 run scoreboard players set @s knock 4")
            hurt.runCommandAsync("scoreboard players remove @s knock 4")
            victim.runCommandAsync("scoreboard players add @s knock 10")
        }
    }

})
world.events.entityHit.subscribe(r => {
    const victim = r.hitEntity
    const hurt = r.entity
    if (!victim) return;
    if (!hurt) return;
    if (victim.typeId == "s:real_door") {
        victim.runCommandAsync("playanimation @s animation.tuer")
        victim.runCommandAsync("fill ~-1 ~ ~-1 ~1 ~3 ~-2 air")
        victim.runCommandAsync("event entity @s despawn")
        hurt.runCommandAsync("playsound note.pling @s")
    }
    if (victim.typeId == "s:broken") {
        hurt.runCommandAsync("scoreboard players add @s so 1")
        victim.runCommandAsync("particle s:plus ~ ~ ~")
        victim.runCommandAsync("event entity @s despawn")
        hurt.runCommandAsync("playsound note.pling @s")
    }
    if (victim.typeId == "s:krone_k") {
        hurt.runCommandAsync("scoreboard players add @s so 1")
        victim.runCommandAsync("particle s:plus ~ ~ ~")
        victim.runCommandAsync("event entity @s despawn")
        hurt.runCommandAsync("playsound note.pling @s")
    }
    if (victim.typeId == "s:magic_hat_b") {
        hurt.runCommandAsync("scoreboard players add @s so 1")
        victim.runCommandAsync("particle s:plus ~ ~ ~")
        victim.runCommandAsync("event entity @s despawn")
        hurt.runCommandAsync("playsound note.pling @s")
    }
    if (victim.typeId == "s:sparta") {
        hurt.runCommandAsync("scoreboard players remove @s so 1")
        victim.runCommandAsync("particle s:minus ~ ~ ~")
        victim.runCommandAsync("event entity @s despawn")
        hurt.runCommandAsync("playsound beacon.deactivate @s")
    }
    if (victim.typeId == "s:krone") {
        hurt.runCommandAsync("scoreboard players remove @s so 1")
        victim.runCommandAsync("particle s:minus ~ ~ ~")
        victim.runCommandAsync("event entity @s despawn")
        hurt.runCommandAsync("playsound beacon.deactivate @s")
    }
    if (victim.typeId == "s:magic_hat") {
        hurt.runCommandAsync("scoreboard players remove @s so 1")
        victim.runCommandAsync("particle s:minus ~ ~ ~")
        victim.runCommandAsync("event entity @s despawn")
        hurt.runCommandAsync("playsound beacon.deactivate @s")
    }
})



